import React, {Component} from 'react';
import {WingBlank, WhiteSpace, ActionSheet, ActivityIndicator} from 'antd-mobile'
import './index.less'
import TopTabs from '../../components/BlankTabs'
import Basic from './Basic'
import Adjunct from './Adjunct'
import Flow from './Flow';
import Option from './Option';

//Ipone antd-mobile ActionSheet
const isIPhone = new RegExp('\\biPhone\\b|\\biPod\\b', 'i').test(window.navigator.userAgent);
let wrapProps;
if (isIPhone) {
    wrapProps = {
        onTouchStart: e => e.preventDefault(),
    };
}

class Process extends Component {
    constructor() {
        super();
        this.optionBlur = this.optionBlur.bind(this)
        this.handleScroll = this.handleScroll.bind(this)
        this.state = {
            current: 'basic',
            disabled: true,
            footStatus: false,
            footButton: '处理',
            loading: false
        }
    };
    componentDidMount() {
        document.getElementsByClassName("option-text")[0].addEventListener('focus', this.optionBlur, true)
        window.addEventListener('scroll', this.handleScroll, true);
    }
    optionBlur = () => {
        this.setState({footButton: '确认发送', footStatus: true})
    }

    componentWillUnmount() {
        document.getElementsByClassName("option-text")[0].removeEventListener('focus', this.optionBlur, true)
        window.removeEventListener('scroll', this.handleScroll, true);
    }
    handleScroll() {
        const adjunct = document.getElementById("event-adjunct").offsetTop;
        const flow = document.getElementById("event-flow").offsetTop;
        const option = document.getElementById("event-option").offsetTop;
        const event = document.getElementById('event');
        const top = event.scrollTop;
        const scrollHeight = event.scrollHeight;
        const clientHeight = event.clientHeight
        if (top >= 0 && top < adjunct) {
            this.setState({current: 'basic'})
        }else if (top >= adjunct && top < flow) {
            this.setState({current: 'adjunct'})
        }else if (top >= flow && top < option) {
            this.setState({current: 'flow'})
        }else if (top >= option) {
            this.setState({current: 'option'})
        }
        if (top + clientHeight === scrollHeight) {
            this.setState({current: 'option'})
        }
    };
    tabClick = (name) => {
        this.setState({current: name})
        name === 'option' && document.getElementsByClassName("option-text")[0].focus();
        name === 'option' && this.optionBlur()
        const top = document.getElementById(`event-${name}`).offsetTop;
        document.getElementById("event").scrollTo(0,top);
    };
    textClick = () => {
        const top = document.getElementById(`event-option`).offsetTop;
        document.getElementById("event").scrollTo(0,top)
        document.getElementsByClassName("option-text")[0].focus();
        this.optionBlur()
    }

    showActionSheet = () => {
        const BUTTONS = ['送部门领导审核', '送办公室分管主任审批', '办结', '取消'];
        ActionSheet.showActionSheetWithOptions({
                options: BUTTONS,
                cancelButtonIndex: BUTTONS.length - 1,
                maskClosable: true,
                wrapProps,
            },
            (buttonIndex) => {
                // console.log(buttonIndex)
            });
    };
    optionChange = val => {
        this.setState({disabled: !(val != null && val != undefined && val != '')})
    }

    render() {
        const {footButton, disabled, footStatus, current, loading} = this.state
        return (
            <div>
                <ActivityIndicator
                    toast
                    text="加载中..."
                    animating={loading}
                />
                <TopTabs page={current} onClick={this.tabClick}/>
                <div id="event">
                    <WingBlank>
                        <div id="event-basic"/>
                        <WhiteSpace/>
                        <Basic/>
                        <div id="event-adjunct"/>
                        <WhiteSpace/>
                        <Adjunct/>
                        <div id="event-flow"/>
                        <WhiteSpace/>
                        <Flow/>
                        <div id="event-option"/>
                        <WhiteSpace/>
                        <Option onChange={this.optionChange}/>
                    </WingBlank>
                </div>
                <div className="event-footer">
                    <div className={`event-footer-button ${(footStatus && disabled) ? 'button-disabled' : '' }`} onClick={footStatus && !disabled ? this.showActionSheet: this.textClick}>
                        {!footStatus && (
                            <img alt="" src="/img/process-edit.png" className="process-edit"/>
                        )}
                        {footButton}
                    </div>

                </div>

            </div>
        );
    }
}

export default Process;
